@@ -474,12 +474,6 @@ void grad_decrypt_tunnel_password(char *password, u_char *tag,
 				  grad_avp_t *pair,
 				  u_char *authenticator, char *secret);
 
-/* gethost_r.c */
-struct hostent *grad_gethostbyname_r(const char *name, struct hostent *result,
-				     char *buffer, int buflen, int *h_errnop);
-struct hostent *grad_gethostbyaddr_r(const char *addr, int length,
-				     int type, struct hostent *result,
-				     char *buffer, int buflen, int *h_errnop);
 
 struct passwd *grad_getpwnam_r(const char *name, struct passwd *result,
 			       char *buffer, int buflen);
@@ -575,6 +569,7 @@ void grad_default_logger(int level,  const grad_request_t *req,
 			 const grad_locus_t *loc,
 			 const char *func_name, int en,
 			 const char *fmt, va_list ap);
+void set_progname(char *argv0);
 
 void grad_log(int level, const char *fmt, ...);
 int __grad_insist_failure(const char *, const char *, int);
