@@ -1,7 +1,5 @@
 /* This file is part of GNU Radius.
-
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -16,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifndef _gnu_radius_radutmp_h
 #define _gnu_radius_radutmp_h
@@ -39,8 +36,8 @@ struct radutmp {
         int  nas_port;                  /* Port on the terminal server */
         char session_id[RUT_IDSIZE];    /* Radius session ID */
                                         /* (last RUT_IDSIZE bytes at least)*/
-        grad_uint32_t nas_address;      /* IP of the NAS */
-        grad_uint32_t framed_address;   /* SLIP/PPP address or login-host. */
+        uint32_t nas_address;      /* IP of the NAS */
+        uint32_t framed_address;   /* SLIP/PPP address or login-host. */
         int proto;                      /* Protocol. */
         time_t time;                    /* Time the entry was last updated. */
         time_t delay;                   /* Delay time of request */
@@ -48,7 +45,7 @@ struct radutmp {
         int porttype;                   /* Value of NAS-Port-Type attr */
         time_t duration;
         char caller_id[RUT_PNSIZE];     /* calling station ID */
-        grad_uint32_t realm_address;
+        uint32_t realm_address;
         char reserved[10];              
 };
 
@@ -62,11 +59,11 @@ struct maxsession {
 
 typedef struct port_stat {
         struct port_stat *next;
-        grad_uint32_t ip;          /* NAS IP */
+        uint32_t ip;          /* NAS IP */
         int port_no;               /* port number */
         int active;                /* is the port used now */
         char login[RUT_NAMESIZE];  /* last login name */
-        grad_uint32_t framed_address; /* IP address assigned to that port */
+        uint32_t framed_address; /* IP address assigned to that port */
         unsigned long count;       /* number of logins */
         time_t start;
         time_t lastin;             /* last time the user logged in */
@@ -101,6 +98,7 @@ int grad_radutent_print(format_data_t *form, struct radutmp *up, int nl);
 format_data_t *grad_radutent_compile_form(char *fmt);
 void grad_utent_print_header(format_data_t *form);
 format_data_t *grad_utent_compile_form(char *fmt);
+int grad_utent_print(format_data_t *form, struct radutmp *up, int newline);
 
 extern int grad_printutmp_ip_nodomain; /* do not display domain names */
 extern int grad_printutmp_use_naslist; /* use naslist when displaying nas names */
