@@ -1,5 +1,6 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2001, 2002, 2003, 2007, 2010, 2013 Free Software
+   Foundation, Inc.
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
@@ -13,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 typedef struct wtmp_chain WTMP;
 struct wtmp_chain {
