@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -13,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -82,7 +80,7 @@ grad_dbm_create(char *name, DBM_FILE *dbmfile)
         p = grad_emalloc(strlen(name)+5);
         strcat(strcpy(p, name), ".pag");
         fd = open(p, O_WRONLY | O_CREAT | O_TRUNC, 0600);
-        grad_free(p);
+        free(p);
         if (fd < 0) 
                 return 1;
         close(fd);
@@ -90,7 +88,7 @@ grad_dbm_create(char *name, DBM_FILE *dbmfile)
         p = grad_emalloc(strlen(name)+5);
         strcat(strcpy(p, name), ".dir");
         fd = open(p, O_WRONLY | O_CREAT | O_TRUNC, 0600);
-        grad_free(p);
+        free(p);
         if (fd < 0) 
                 return 1;
         close(fd);
