@@ -26,7 +26,18 @@
 #include <time.h>
 #include <errno.h>
 #include <common.h>
-#include <argp.h>
+
+char *progname;
+
+void
+set_progname(char *argv0)
+{
+	progname = strrchr(argv0, '/');
+	if (progname)
+		progname++;
+	else
+		progname = argv0;
+}
 
 static char *priname[] = { /* priority names */
         "emerg",
@@ -46,7 +57,7 @@ grad_default_logger(int level,
 		    const char *func_name, int en,
 		    const char *fmt, va_list ap)
 {
-        fprintf(stderr, "%s: %s: ", program_invocation_short_name,
+        fprintf(stderr, "%s: %s: ", progname,
 		priname[level & GRAD_LOG_PRIMASK]);
         if (loc) {
                 fprintf(stderr, "%s:%lu:", loc->file, (unsigned long) loc->line);
