@@ -1,6 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007,2008 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -14,10 +13,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public
-   License along with GNU Radius; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA. */
+   You should have received a copy of the GNU General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -83,9 +80,9 @@ format_key_free(format_key_t *key)
 	format_key_t *next;
 	while (key) {
 		next = key->next;
-		grad_free(key->name);
-		grad_free(key->value);
-		grad_free(key);
+		free(key->name);
+		free(key->value);
+		free(key);
 		key = next;
 	}
 }
@@ -111,15 +108,15 @@ form_free(format_data_t *form)
 		format_key_free(form->key);
 		switch (form->type) {
 		case FDATA_STRING:
-			grad_free(form->v.string);
+			free(form->v.string);
 			break;
 		case FDATA_FH:
-			grad_free(form->v.fh.header);
+			free(form->v.fh.header);
 			break;
 		default:
 			break;
 		}
-		grad_free(form);
+		free(form);
 
 		form = next;
 	}
@@ -184,9 +181,9 @@ output_tab(int column, int tabstop)
 }
 
 static char *
-get_hostname(grad_uint32_t ipaddr, int nodomain, char *buf, size_t size)
+get_hostname(uint32_t ipaddr, int nodomain, char *buf, size_t size)
 {
-        if (ipaddr == 0 || ipaddr == (grad_uint32_t)-1 || ipaddr == (grad_uint32_t)-2)
+        if (ipaddr == 0 || ipaddr == (uint32_t)-1 || ipaddr == (uint32_t)-2)
                 return "";
 
         if (nodomain) {
@@ -205,7 +202,7 @@ get_hostname(grad_uint32_t ipaddr, int nodomain, char *buf, size_t size)
 }
 
 static int
-output_hostname(grad_uint32_t ip, int width, format_key_t *key)
+output_hostname(uint32_t ip, int width, format_key_t *key)
 {
 	char buf[80];
 	return output_string_key(get_hostname(ip, key_nodomain(key),
@@ -216,12 +213,11 @@ output_hostname(grad_uint32_t ip, int width, format_key_t *key)
 static int
 output_time(time_t t, int width, format_key_t *key)
 {
-        int d,h,m,s;
+        int d,h,m;
 	
         d = t / 86400;
         t %= 86400;
         
-        s = t % 60;
         m = t / 60;
         if (m > 59) {
                 h = m / 60;
@@ -257,7 +253,8 @@ gecos_fh(int outbytes, int width, format_key_t *key, struct radutmp *up)
         char *s;
 	char buffer[512];
 
-        if (pwd = grad_getpwnam_r(up->login, &pw, buffer, sizeof buffer)) {
+	pwd = grad_getpwnam_r(up->login, &pw, buffer, sizeof buffer);
+        if (pwd) {
                 if ((s = strchr(pwd->pw_gecos, ',')) != NULL)
                         *s = 0;
                 s = pwd->pw_gecos;
