@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -76,7 +75,7 @@ _sym_add(grad_symtab_t *symtab, unsigned h, grad_symbol_t *sp)
 }
 
 grad_symtab_t *
-grad_symtab_create(unsigned esize, int (*elfree)())
+grad_symtab_create(unsigned esize, void (*elfree)(void *))
 {
         grad_symtab_t *symtab;
         
@@ -100,7 +99,8 @@ grad_symtab_rehash(grad_symtab_t *symtab)
                 abort();
         }
 
-        symtab->sym = grad_emalloc(hash_size[symtab->hash_num] * symtab->elsize);
+        symtab->sym = grad_ecalloc(hash_size[symtab->hash_num],
+				   symtab->elsize);
 
         if (old_table) {
                 size_t old_size = hash_size[symtab->hash_num-1];
@@ -120,7 +120,7 @@ grad_symtab_rehash(grad_symtab_t *symtab)
                                 sym = next;
                         }
                 }
-                grad_free (old_table);
+                free (old_table);
         }
         return 0;
 }
@@ -234,8 +234,8 @@ grad_symtab_delete(grad_symtab_t *symtab, grad_symbol_t *sym)
 void
 grad_sym_free(grad_symbol_t *sp)
 {
-        grad_free(sp->name);
-        grad_free(sp);
+        free(sp->name);
+        free(sp);
 }
 
 void
@@ -265,8 +265,8 @@ grad_symtab_free(grad_symtab_t **symtab)
 	if (!symtab || !*symtab)
 		return;
         grad_symtab_clear(*symtab);
-        grad_free((*symtab)->sym);
-        grad_free(*symtab);
+        free((*symtab)->sym);
+        free(*symtab);
         *symtab = NULL;
 }
 
