@@ -363,7 +363,7 @@ typedef struct auth_mach {
         char       userpass[GRAD_STRING_LENGTH+1];
 
         char       *user_msg;
-        struct obstack msg_stack;
+        grad_strbuf_t msg_buf;
         
         enum auth_state state;
 } AUTH_MACH;
@@ -492,17 +492,17 @@ void
 auth_format_msg(AUTH_MACH *m, int msg_id)
 {
         int len = strlen(message_text[msg_id]);
-        obstack_grow(&m->msg_stack, message_text[msg_id], len);
+        grad_strbuf_grow(m->msg_buf, message_text[msg_id], len);
 }
 
 char *
 auth_finish_msg(AUTH_MACH *m)
 {
         if (m->user_msg)
-                obstack_grow(&m->msg_stack, m->user_msg, strlen(m->user_msg));
-        obstack_1grow(&m->msg_stack, 0);
-        return radius_xlate(&m->msg_stack, obstack_finish(&m->msg_stack),
-                            m->req->request, m->user_reply);
+                grad_strbuf_grow(m->msg_buf, m->user_msg, strlen(m->user_msg));
+        radius_strbuf_xlate(m->msg_buf, grad_strbuf_finish(m->msg_buf, 0),
+			    m->req->request, m->user_reply);
+	return grad_strbuf_finish(m->msg_buf, 0);
 }
 
 /* Check password. */
@@ -592,13 +592,13 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
         /* Process any prefixes/suffixes. */
         strip_username(1, m->namepair->avp_strvalue, m->user_check, name);
 
-        GRAD_DEBUG4(1, "auth_type=%d, userpass=%s, name=%s, password=%s",
+        GRAD_DEBUG(1, "auth_type=%d, userpass=%s, name=%s, password=%s",
 	            auth_type, m->userpass, name,
 	            real_password ? real_password : "NONE");
 
         switch (auth_type) {
         case DV_AUTH_TYPE_SYSTEM:
-                GRAD_DEBUG(1, "auth: System");
+                GRAD_DEBUG(1, "%s",  "auth: System");
                 if (unix_pass(name, m->userpass) != 0)
                         result = auth_fail;
 		else
@@ -607,7 +607,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
 		
         case DV_AUTH_TYPE_PAM:
 #ifdef USE_PAM
-                GRAD_DEBUG(1, "auth: Pam");
+                GRAD_DEBUG(1, "%s",  "auth: Pam");
                 /* Provide defaults for authdata */
                 if (authdata == NULL &&
                     (tmp = grad_avl_find(m->user_check, DA_PAM_AUTH)) != NULL) {
@@ -624,7 +624,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                 break;
 
         case DV_AUTH_TYPE_CRYPT_LOCAL:
-                GRAD_DEBUG(1, "auth: Crypt");
+                GRAD_DEBUG(1, "%s",  "auth: Crypt");
                 if (real_password == NULL) {
                         result = auth_fail;
                         break;
@@ -635,12 +635,12 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                         result = auth_fail;
                 else if (strcmp(real_password, pwbuf) != 0)
                         result = auth_fail;
-                GRAD_DEBUG1(1, "pwbuf: %s", pwbuf);
+                GRAD_DEBUG(1, "pwbuf: %s", pwbuf);
                 free(pwbuf);
                 break;
                 
         case DV_AUTH_TYPE_LOCAL:
-                GRAD_DEBUG(1, "auth: Local");
+                GRAD_DEBUG(1, "%s",  "auth: Local");
                 /* Local password is just plain text. */
                 if (auth_item->attribute != DA_CHAP_PASSWORD) {
                         if (real_password == NULL ||
@@ -750,11 +750,11 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
         m.user_reply = NULL;
         m.check_pair = NULL;
         m.user_msg   = NULL;
-        obstack_init(&m.msg_stack);
+	m.msg_buf    = grad_strbuf_create();
 
         m.namepair = grad_avl_find(m.req->request->avlist, DA_USER_NAME);
 
-        GRAD_DEBUG1(1, "auth: %s", m.namepair->avp_strvalue); 
+        GRAD_DEBUG(1, "auth: %s", m.namepair->avp_strvalue); 
         m.state = as_init;
 
         while (m.state != as_stop) {
@@ -794,14 +794,14 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
         grad_avl_free(m.user_reply);
         if (m.user_msg)
                 free(m.user_msg);
-        obstack_free(&m.msg_stack, NULL);
+        grad_strbuf_free(m.msg_buf);
         memset(m.userpass, 0, sizeof(m.userpass));
         return 0;
 }
 
 #if RADIUS_DEBUG
 # define newstate(s) do {\
-             GRAD_DEBUG2(2, "%d -> %d", m->state, s);\
+             GRAD_DEBUG(2, "%d -> %d", m->state, s);\
              m->state = s;\
   } while (0)
 #else
@@ -914,7 +914,7 @@ auth_failure(AUTH_MACH *m)
 	if (!pair) 
 		return;
 
-	cmd = util_xlate(&m->msg_stack, pair->avp_strvalue, m->req->request);
+	cmd = util_xlate(m->msg_buf, pair->avp_strvalue, m->req->request);
 	switch (cmd[0]) {
 	case '(':
 		scheme_eval_unspecified_expr(cmd);
@@ -1117,7 +1117,7 @@ sfn_time(AUTH_MACH *m)
                  * User is allowed, but set Session-Timeout.
                  */
                 uint32_t to = set_session_timeout(m, rest);
-                GRAD_DEBUG4(2, "user %s, span %s, timeout %d, real timeout %d",
+                GRAD_DEBUG(2, "user %s, span %s, timeout %d, real timeout %d",
                             m->namepair->avp_strvalue,
                             m->check_pair->avp_strvalue,
                             rest,
@@ -1217,7 +1217,7 @@ sfn_menu_challenge(AUTH_MACH *m)
         radius_send_challenge(m->req, msg, state_value, m->activefd);
         free(msg);
 	
-        GRAD_DEBUG2(1, "sending challenge (menu %s) to %s",
+        GRAD_DEBUG(1, "sending challenge (menu %s) to %s",
                     m->check_pair->avp_strvalue, m->namepair->avp_strvalue);
         newstate(as_stop);
 #endif  
@@ -1226,7 +1226,7 @@ sfn_menu_challenge(AUTH_MACH *m)
 void
 sfn_ack(AUTH_MACH *m)
 {
-        GRAD_DEBUG1(1, "ACK: %s", m->namepair->avp_strvalue);
+        GRAD_DEBUG(1, "ACK: %s", m->namepair->avp_strvalue);
         
 	radius_eval_avl(m->req, m->user_reply);
 
@@ -1254,7 +1254,7 @@ sfn_reject_cleanup(AUTH_MACH *m)
 void
 sfn_reject(AUTH_MACH *m)
 {
-        GRAD_DEBUG1(1, "REJECT: %s", m->namepair->avp_strvalue);
+        GRAD_DEBUG(1, "REJECT: %s", m->namepair->avp_strvalue);
 	radius_eval_avl(m->req, m->user_reply);
         radius_send_reply(RT_ACCESS_REJECT,
                           m->req,
