@@ -48,7 +48,7 @@ _free_loaded_module (void *item, void *data)
 	lt_dlhandle handle = (lt_dlhandle) item;
 	grad_dl_done_t fp = (grad_dl_done_t) lt_dlsym(handle, "done");
 
-	GRAD_DEBUG2(1,"Freeing handle %p, grad_dl_done %p", handle, fp);
+	GRAD_DEBUG(1,"Freeing handle %p, grad_dl_done %p", handle, fp);
 	if (fp)
 		fp();
 	lt_dlclose(handle);
@@ -68,9 +68,9 @@ radiusd_load_ext(const char *name, const char *ident, void **symbol)
 {
 	lt_dlhandle handle;
 
-	GRAD_DEBUG2(1,"Loading module '%s', symbol '%s'", name, ident);
+	GRAD_DEBUG(1,"Loading module '%s', symbol '%s'", name, ident);
 	if (lt_dlinit()) {
-		GRAD_DEBUG(1,"lt_ldinit failed");
+		GRAD_DEBUG(1, "%s", "lt_ldinit failed");
 		return NULL;
 	}
 	
@@ -101,7 +101,7 @@ radiusd_load_ext(const char *name, const char *ident, void **symbol)
 		grad_log(GRAD_LOG_NOTICE, _("Cannot load module %s: %s"),
 			 name, lt_dlerror());
 
-	GRAD_DEBUG1(1,"Handle %p", handle);
+	GRAD_DEBUG(1,"Handle %p", handle);
 	if (!handle) 
 		lt_dlexit();
 	else
@@ -135,21 +135,21 @@ dynload_free_modules(void)
 void *
 radiusd_load_ext(const char *name, const char *ident, void **symbol)
 {
-	GRAD_DEBUG(1,"radiusd is compiled without dynamic loading support");
+	GRAD_DEBUG(1, "%s", "radiusd is compiled without dynamic loading support");
 	return NULL;
 }
 
 int
 radiusd_add_load_path(const char *path)
 {
-	GRAD_DEBUG(1,"radiusd is compiled without dynamic loading support");
+	GRAD_DEBUG(1, "%s", "radiusd is compiled without dynamic loading support");
 	return 1;
 }
 
 int
 radiusd_set_load_path(const char *path)
 {
-	GRAD_DEBUG(1,"radiusd is compiled without dynamic loading support");
+	GRAD_DEBUG(1, "%s", "radiusd is compiled without dynamic loading support");
 	return 1;
 }
 
