@@ -100,12 +100,12 @@ proxy_cmp(radiusd_request_t *qr, radiusd_request_t *r)
 	grad_server_t *server;
 	
 	if (!qr->realm) {
-		GRAD_DEBUG(100,"no proxy realm");
+		GRAD_DEBUG(100, "%s", "no proxy realm");
 		return 1;
 	}
 	server = grad_list_item(qr->realm->queue->servers, qr->server_no);
 	if (!server) {
-		GRAD_DEBUG(100,"no proxy server");
+		GRAD_DEBUG(100, "%s", "no proxy server");
 		return 1;
 	}
 	
@@ -121,7 +121,7 @@ proxy_cmp(radiusd_request_t *qr, radiusd_request_t *r)
 
 		state = (PROXY_STATE *)proxy_state_pair->avp_strvalue;
 	
-		GRAD_DEBUG4(1,
+		GRAD_DEBUG(1,
 		      "state: ipaddr %08x, id %u, proxy_id %u, remote_ip %08x",
 		       state->client_ip,
 		       state->id,
@@ -131,7 +131,7 @@ proxy_cmp(radiusd_request_t *qr, radiusd_request_t *r)
                 if (state->ref_ip == ref_ip
 		    && state->proxy_id == r->request->id
 		    && state->remote_ip == r->request->ipaddr) {
-			GRAD_DEBUG8(10, 
+			GRAD_DEBUG(10, 
                                     "(old=data) id %d %d, ipaddr %#8x %#8x, "
                                     "proxy_id %d %d, server_addr %#8x %#8x", 
 				    qr->request->id, state->id,
@@ -143,7 +143,7 @@ proxy_cmp(radiusd_request_t *qr, radiusd_request_t *r)
 			    && state->id  == qr->request->id
 			    && state->proxy_id == qr->server_id
 			    && state->remote_ip == server->addr) {
-				GRAD_DEBUG(1,"EQUAL!!!");
+				GRAD_DEBUG(1, "%s", "EQUAL!!!");
 				return 0;
 			}
 		} 
@@ -170,7 +170,7 @@ proxy_send_pdu(int fd, grad_server_t *server, radiusd_request_t *radreq,
 			     server->port[GRAD_PORT_AUTH] 
 			     : server->port[GRAD_PORT_ACCT]);
 
-	GRAD_DEBUG2(1, "Proxying id %d to %lx",
+	GRAD_DEBUG(1, "Proxying id %d to %lx",
 		    radreq->request->id, (u_long)server->addr);
 
 	return sendto(fd, pdu, size, 0, (struct sockaddr *)&sin, sizeof(sin));
@@ -249,7 +249,7 @@ proxy_send_request(int fd, radiusd_request_t *radreq)
 		upd->server_no = radreq->server_no;
 		strcpy(upd->realmname, radreq->realm->realm);
 
-		GRAD_DEBUG4(100,
+		GRAD_DEBUG(100,
 		      "Update id=%d, proxy_id=%d, realm=%s, server_no=%d",
 		       upd->id,upd->proxy_id,upd->realmname,
 		       upd->server_no);
