@@ -28,33 +28,6 @@
 #include <radiusd.h>
 #include <rewrite.h>
 
-/* obstack_grow with quoting of potentially dangerous characters */
-static void
-obstack_grow_escaped(struct obstack *obp, char *str, int len)
-{
-        for (; len > 0; len--, str++) {
-                switch (*str) {
-                case '"':
-                case '\'':
-                case '\\':
-                        obstack_1grow(obp, '\\');
-			obstack_1grow(obp, *str);
-			break;
-			
-                default:
-			if (isprint(*str))
-				obstack_1grow(obp, *str);
-			else {
-				char buf[4];
-				snprintf(buf, sizeof(buf), "%03o",
-					 *(u_char*)str);
-				obstack_1grow(obp, '\\');
-				obstack_grow(obp, buf, 3);
-			}
-                }
-        }
-}
-
 /*
  *      Replace %<whatever> in a string.
  *
@@ -78,13 +51,13 @@ obstack_grow_escaped(struct obstack *obp, char *str, int len)
  */
 
 /* Find attribute `attr' in pairlist `pairlist' and store it's formatted
- * value into obstack.
+ * value into strbuf.
  * If no attribute found, store the provided default value (defval). If
  * the latter is NULL, store "unknown" for string type and "0" for
  * others.
  */
 static void
-attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
+attr_to_str(grad_strbuf_t obp, grad_request_t *req, grad_avp_t *pairlist,
             grad_dict_attr_t  *attr, char *defval, int escape)
 {
         grad_avp_t *pair;
@@ -108,7 +81,7 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
                 switch (*defval++) {
                 case '-':
                         len = strlen(defval);
-                        obstack_grow(obp, defval, len);
+                        grad_strbuf_grow(obp, defval, len);
                         break;
                 case '+':
                         break;
@@ -145,7 +118,7 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
         } else if (defval && *defval == '+') {
                 defval++;
                 len = strlen(defval);
-                obstack_grow(obp, defval, len);
+                grad_strbuf_grow(obp, defval, len);
                 return;
         }
 
@@ -165,9 +138,9 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
 			   character, so we need to recalculate it */
 			len = strlen(str);
 		if (escape)
-			obstack_grow_escaped(obp, str, len);
+			grad_strbuf_grow_escape(obp, str, len);
 		else
-			obstack_grow(obp, str, len);
+			grad_strbuf_grow(obp, str, len);
                 break;
 		
         case GRAD_TYPE_INTEGER:
@@ -182,22 +155,22 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
                 if (!dval) {
 			snprintf(tmp, sizeof(tmp), "%"PRIu32, pair->avp_lvalue);
 			len = strlen(tmp);
-			obstack_grow(obp, tmp, len);
+			grad_strbuf_grow(obp, tmp, len);
 		} else 
-			obstack_grow(obp, dval->name, strlen (dval->name));
+			grad_strbuf_grow(obp, dval->name, strlen (dval->name));
 		break;
 	}
 		
         case GRAD_TYPE_IPADDR:
                 grad_ip_iptostr(pair->avp_lvalue, tmp);
                 len = strlen(tmp);
-                obstack_grow(obp, tmp, len);
+                grad_strbuf_grow(obp, tmp, len);
                 break;
 		
         case GRAD_TYPE_DATE:
                 snprintf(tmp, sizeof(tmp), "%"PRIu32, pair->avp_lvalue);
                 len = strlen(tmp);
-                obstack_grow(obp, tmp, len);
+                grad_strbuf_grow(obp, tmp, len);
                 break;
 		
         default:
@@ -210,7 +183,7 @@ attr_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
 }
 
 static void
-curtime_to_str(struct obstack *obp, grad_avp_t *request, int gmt)
+curtime_to_str(grad_strbuf_t obp, grad_avp_t *request, int gmt)
 {
         time_t curtime;
         struct tm *tm, tms;
@@ -227,16 +200,16 @@ curtime_to_str(struct obstack *obp, grad_avp_t *request, int gmt)
                 tm = localtime_r(&curtime, &tms);
                                 
         len = strftime(tbuf, GRAD_STRING_LENGTH, "%Y-%m-%d %H:%M:%S", tm);
-        obstack_grow(obp, tbuf, len);
+        grad_strbuf_grow(obp, tbuf, len);
 }
 
 /* Find attribute number `attr_no' in pairlist `pairlist' and store it's
- * formatted value into obstack.
+ * formatted value into strbuf.
  * If no attribute found, use provided default value (see comment to
  * attr_to_str)
  */
 static void
-attrno_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
+attrno_to_str(grad_strbuf_t obp, grad_request_t *req, grad_avp_t *pairlist,
               int attr_no, char *defval, int escape_str)
 {
         attr_to_str(obp, req, pairlist,
@@ -244,7 +217,7 @@ attrno_to_str(struct obstack *obp, grad_request_t *req, grad_avp_t *pairlist,
 }
 
 static grad_dict_attr_t *
-parse_dict_attr(char *p, char **endp, char **defval)
+parse_dict_attr(char const *p, char **endp, char **defval)
 {
         char namebuf[GRAD_MAX_DICTNAME];
         
@@ -269,7 +242,7 @@ parse_dict_attr(char *p, char **endp, char **defval)
                 p += off;
                 if (*p == ':') {
                         int size;
-                        char *start = p+1;
+                        char const *start = p+1;
 
                         for (; *p && *p != '}'; p++) {
                                 if (*p == '\\' && *++p == 0)
@@ -283,19 +256,19 @@ parse_dict_attr(char *p, char **endp, char **defval)
                         memcpy(*defval, start, size-1);
                         (*defval)[size-1] = 0;
                 }
-                *endp = p + 1;
+                *endp = (char*) p + 1;
                 return grad_attr_name_to_dict(namebuf);
         }
-        *endp = p;
+        *endp = (char*) p;
         return NULL;
 }
 
 void
-radius_xlate0(struct obstack *obp, char *str, grad_request_t *req,
-              grad_avp_t *reply)
+radius_strbuf_xlate(grad_strbuf_t obp, char const *str, grad_request_t *req,
+		    grad_avp_t *reply)
 {
         int c;
-        char *p;
+        char const *p;
         grad_dict_attr_t *da;
         char *defval;
 	int escape;
@@ -303,26 +276,26 @@ radius_xlate0(struct obstack *obp, char *str, grad_request_t *req,
         for (p = str; *p; ) {
                 switch (c = *p++) {
                 default:
-                        obstack_1grow(obp, c);
+                        grad_strbuf_grow_char(obp, c);
                         break;
 			
                 case 0:
                         goto end;
 			
 		case '\n':
-			obstack_1grow(obp, '\r');
-			obstack_1grow(obp, c);
+			grad_strbuf_grow_char(obp, '\r');
+			grad_strbuf_grow_char(obp, c);
 			break;
 			
                 case '%':
                         if (!req) {
-                                obstack_1grow(obp, c);
+                                grad_strbuf_grow_char(obp, c);
                                 break;
                         }
 			escape = (p > str+1 && (p[-2] == '\'' || p[-2] == '"'));
                         switch (c = *p++) {
                         case '%':
-                                obstack_1grow(obp, c);
+                                grad_strbuf_grow_char(obp, c);
                                 break;
 				
                         case 'D':
@@ -394,7 +367,7 @@ radius_xlate0(struct obstack *obp, char *str, grad_request_t *req,
 					p++;
 				} 
                                 /* Request pair */
-                                da = parse_dict_attr(p, &p, &defval);
+                                da = parse_dict_attr(p, (char**) &p, &defval);
                                 attr_to_str(obp, req, req->avlist,
                                             da, defval, escape);
                                 free(defval);
@@ -406,14 +379,14 @@ radius_xlate0(struct obstack *obp, char *str, grad_request_t *req,
 					p++;
 				}
                                 /* Reply pair */
-                                da = parse_dict_attr(p, &p, &defval);
+                                da = parse_dict_attr(p, (char**) &p, &defval);
                                 attr_to_str(obp, NULL,
                                             reply, da, defval, escape);
                                 break;
 				
                         default:                                        
-                                obstack_1grow(obp, '%');
-                                obstack_1grow(obp, c);
+                                grad_strbuf_grow_char(obp, '%');
+                                grad_strbuf_grow_char(obp, c);
                                 break;
                         }
                         break;
@@ -421,39 +394,39 @@ radius_xlate0(struct obstack *obp, char *str, grad_request_t *req,
                 case '\\':
                         switch (c = *p++) {
                         case 'a':
-                                obstack_1grow(obp, '\a');
+                                grad_strbuf_grow_char(obp, '\a');
                                 break;
 				
                         case 'b':
-                                obstack_1grow(obp, '\b');
+                                grad_strbuf_grow_char(obp, '\b');
                                 break;
 				
                         case 'f':
-                                obstack_1grow(obp, '\f');
+                                grad_strbuf_grow_char(obp, '\f');
                                 break;
 				
                         case 'e':
-                                obstack_1grow(obp, '\033');
+                                grad_strbuf_grow_char(obp, '\033');
                                 break;
 				
                         case 'n':
-                                obstack_1grow(obp, '\n');
+                                grad_strbuf_grow_char(obp, '\n');
                                 break;
 				
                         case 'r':
-                                obstack_1grow(obp, '\r');
+                                grad_strbuf_grow_char(obp, '\r');
                                 break;
 				
                         case 't':
-                                obstack_1grow(obp, '\t');
+                                grad_strbuf_grow_char(obp, '\t');
                                 break;
 				
                         case 0:
                                 goto end;
 				
                         default:
-                                obstack_1grow(obp, '\\');
-                                obstack_1grow(obp, c);
+                                grad_strbuf_grow_char(obp, '\\');
+                                grad_strbuf_grow_char(obp, c);
                                 break;
                         }
                 }
@@ -463,19 +436,19 @@ end:
 }
 
 char *
-radius_xlate(struct obstack *obp, char *str,
-	     grad_request_t *req, grad_avp_t *reply)
+radius_xlate(char const *str, grad_request_t *req, grad_avp_t *reply)
 {
-        radius_xlate0(obp, str, req, reply);
-        obstack_1grow(obp, 0);
-        return obstack_finish(obp);
+	grad_strbuf_t sb = grad_strbuf_create();
+	char *p;
+        radius_strbuf_xlate(sb, str, req, reply);
+	p = grad_strbuf_finish(sb, 1);
+	grad_strbuf_free(sb);
+	return p;
 }
 
 char *
-util_xlate(struct obstack *sp, char *fmt, grad_request_t *radreq)
+util_xlate(grad_strbuf_t sp, char const *fmt, grad_request_t *radreq)
 {
-	char *str;
-	
 	if (fmt[0] == '=') {
 		grad_value_t val;
 		
@@ -488,13 +461,13 @@ util_xlate(struct obstack *sp, char *fmt, grad_request_t *radreq)
 			/* Nothing to free in val */
 			return NULL;
 		}
-		obstack_grow(sp, val.datum.sval.data, val.datum.sval.size + 1);
+		grad_strbuf_grow(sp, val.datum.sval.data,
+				 val.datum.sval.size + 1);
 		grad_value_free(&val);
-		str = obstack_finish(sp);
 	} else {
-		str = radius_xlate(sp, fmt, radreq, NULL);
+		radius_strbuf_xlate(sp, fmt, radreq, NULL);
 	}
-	return str;
+	return grad_strbuf_finish(sp, 0);
 }
 
 static void
@@ -560,16 +533,14 @@ radius_eval_avp(radiusd_request_t *req, grad_avp_t *p, grad_avp_t *reply,
 	switch (p->eval_type) {
 	case grad_eval_const:
 		if (allow_xlate && strchr(p->avp_strvalue, '%')) {
-			struct obstack s;
 			char *ptr;
-			obstack_init (&s);
-			ptr = radius_xlate(&s, p->avp_strvalue,
+			ptr = radius_xlate(p->avp_strvalue,
 					   req->request, reply);
 			if (strcmp(ptr, p->avp_strvalue)) {
 				grad_string_replace(&p->avp_strvalue, ptr);
-				p->avp_strlength = strlen (p->avp_strvalue);
+				p->avp_strlength = strlen(p->avp_strvalue);
 			}
-			obstack_free (&s, NULL);
+			free(ptr);
 		}
 		break;
 			
