@@ -201,7 +201,7 @@ _request_iterator(void *item, void *clos)
 	if (req->status == RS_COMPLETED) {
 		if (req->timestamp + request_class[req->type].cleanup_delay
 		             <= rp->curtime) {
-			GRAD_DEBUG1(1, "deleting completed %s request",
+			GRAD_DEBUG(1, "deleting completed %s request",
 				    request_class[req->type].name);
 			grad_list_remove(request_list, req, NULL);
 			request_free(req);
@@ -213,7 +213,7 @@ _request_iterator(void *item, void *clos)
 			   
 	} else if (req->status == RS_PROXY) {
 		if (!spawn_flag || rpp_ready(req->child_id)) {
-			GRAD_DEBUG2(1, "%s proxy reply. Process %lu", 
+			GRAD_DEBUG(1, "%s proxy reply. Process %lu", 
 				    request_class[req->type].name,
 				    (u_long) req->child_id);
 			request_call_handler(rp->handler, req);
@@ -332,20 +332,20 @@ request_handle(REQUEST *req, int (*handler)(REQUEST *))
 		req->orig = rc.orig;
 		req->child_id = rc.orig->child_id;
 		if (!radiusd_master()) {
-			GRAD_DEBUG2(1, "%s proxy reply. Process %lu", 
+			GRAD_DEBUG(1, "%s proxy reply. Process %lu", 
 				    request_class[req->type].name,
 				    (u_long) req->child_id);
 			request_call_handler(handler, req);
 		} else {
 			if (!spawn_flag || rpp_ready(req->child_id)) {
-				GRAD_DEBUG2(1, "%s proxy reply. Process %lu", 
+				GRAD_DEBUG(1, "%s proxy reply. Process %lu", 
 					    request_class[req->type].name,
 					    (u_long) req->child_id);
 				request_call_handler(handler, req);
 			} else {
 				req->status = RS_PROXY;
 				/* Add request to the queue */
-				GRAD_DEBUG3(1, 
+				GRAD_DEBUG(1, 
                                             "Proxy %s request %lu added to the "
                                             "list. %d requests held.", 
 					    request_class[req->type].name,
@@ -383,7 +383,7 @@ request_handle(REQUEST *req, int (*handler)(REQUEST *))
 	}
 
 	if (rc.lru) {
-		GRAD_DEBUG1(1, "replacing request dated %s",
+		GRAD_DEBUG(1, "replacing request dated %s",
 			    ctime(&rc.lru->timestamp));
 		grad_list_remove(request_list, rc.lru, NULL);
 		request_free(rc.lru);
@@ -391,7 +391,7 @@ request_handle(REQUEST *req, int (*handler)(REQUEST *))
 	}
 	
 	/* Add request to the queue */
-        GRAD_DEBUG3(1, "%s request %lu added to the list. %d requests held.", 
+        GRAD_DEBUG(1, "%s request %lu added to the list. %d requests held.", 
                   request_class[req->type].name,
                   (u_long) req->child_id,
                   rc.request_count+1);
@@ -408,7 +408,7 @@ request_update(pid_t pid, int status, void *ptr)
 	REQUEST *p;
 	grad_iterator_t *itr;
 	
-	GRAD_DEBUG2(100,"enter, pid=%lu, ptr = %p", (unsigned long)pid, ptr);
+	GRAD_DEBUG(100,"enter, pid=%lu, ptr = %p", (unsigned long)pid, ptr);
 	itr = grad_iterator_create(request_list);
 	if (!itr)
 		return;
@@ -420,7 +420,7 @@ request_update(pid_t pid, int status, void *ptr)
 		}
 	}
 	grad_iterator_destroy(&itr);
-	GRAD_DEBUG(100,"exit");
+	GRAD_DEBUG(100, "%s", "exit");
 }
 			
 
