@@ -852,7 +852,7 @@ mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
         struct snmp_var *temp_var;
         struct mib_node_t *found_node;
         
-        GRAD_DEBUG1(2, "OID %s",
+        GRAD_DEBUG(2, "OID %s",
                     sprint_oid(buf, sizeof(buf), (*varp)->name));
         
         /* first, find the node itself */
@@ -886,7 +886,7 @@ mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
                 if (!node) {
                         /* The subtree is exhausted. Roll back until we find
                            first non-traversed down link */
-                        GRAD_DEBUG2(2, "rolling back from %d:%d",
+                        GRAD_DEBUG(2, "rolling back from %d:%d",
                                     found_node->index,
                                     found_node->subid);
                         while ((node = found_node->up) != NULL) {
@@ -900,7 +900,7 @@ mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
                         }
 
                         if (node)
-                                GRAD_DEBUG2(2, "rollback stopped at %d:%d",
+                                GRAD_DEBUG(2, "rollback stopped at %d:%d",
                                             node->index,
                                             node->subid);
 
@@ -922,7 +922,7 @@ mib_get_next(struct mib_node_t *node, struct snmp_var **varp, int *errp)
         temp_var = snmp_var_create(oid);
         snmp_free(oid);
 
-        GRAD_DEBUG1(2, "NXT %s", sprint_oid(buf, sizeof(buf), temp_var->name));
+        GRAD_DEBUG(2, "NXT %s", sprint_oid(buf, sizeof(buf), temp_var->name));
                          
         *varp = temp_var;
         (*found_node->handler)(MIB_NODE_GET,
@@ -1022,11 +1022,11 @@ snmp_agent_response(struct snmp_pdu *pdu, int access)
                         /* First, check for the consistency of
                          * the request (rfc1157, 4.1.5):
                          */
-                        GRAD_DEBUG(1, "SetRequest-PDU");
+                        GRAD_DEBUG(1, "%s",  "SetRequest-PDU");
                         if (access == SNMP_RO) {
                                 answer->err_stat = SNMP_ERR_GENERR;
                                 answer->err_ind = 1;
-                                GRAD_DEBUG(1,"bad access mode");
+                                GRAD_DEBUG(1, "%s", "bad access mode");
                                 return answer;
                         }
                         for (vp = pdu->var; vp; vp = vp->next) {
@@ -1040,7 +1040,7 @@ snmp_agent_response(struct snmp_pdu *pdu, int access)
                         if (answer->err_stat != SNMP_ERR_NOERROR) {
                                 answer->var = snmp_var_dup_list(pdu->var);
                                 answer->err_ind = index;
-                                GRAD_DEBUG(1, "returning error");
+                                GRAD_DEBUG(1, "%s",  "returning error");
                                 return answer;
                         }
 
@@ -1059,11 +1059,11 @@ snmp_agent_response(struct snmp_pdu *pdu, int access)
                                 vresp = &vnew->next;
                         }
 
-                        GRAD_DEBUG(1, "success");
+                        GRAD_DEBUG(1, "%s",  "success");
                         return answer;
 
                 case SNMP_PDU_GET:
-                        GRAD_DEBUG(1, "GetRequest-PDU");
+                        GRAD_DEBUG(1, "%s",  "GetRequest-PDU");
 
                         vresp = &answer->var;
                         /* Loop through all variables */
@@ -1080,7 +1080,7 @@ snmp_agent_response(struct snmp_pdu *pdu, int access)
                                 if (answer->err_stat != SNMP_ERR_NOERROR
                                     || vnew == NULL) {
                                         answer->err_ind = index;
-                                        GRAD_DEBUG(1,"returning");
+                                        GRAD_DEBUG(1, "%s", "returning");
                                         /* preserve the rest of vars */
                                         *vresp = snmp_var_dup_list(vp);
                                         return answer;
@@ -1095,7 +1095,7 @@ snmp_agent_response(struct snmp_pdu *pdu, int access)
                         return answer;
 
                 case SNMP_PDU_GETNEXT:
-                        GRAD_DEBUG(1, "GetNextRequest-PDU");
+                        GRAD_DEBUG(1, "%s",  "GetNextRequest-PDU");
 
                         vresp = &answer->var;
                         /* Loop through all variables */
@@ -1110,7 +1110,7 @@ snmp_agent_response(struct snmp_pdu *pdu, int access)
                                 if (answer->err_stat != SNMP_ERR_NOERROR
                                     || vnew == NULL) {
                                         answer->err_ind = index;
-                                        GRAD_DEBUG1(1, 
+                                        GRAD_DEBUG(1, 
                                                     "returning: err_stat=%d",
 						     answer->err_stat);
                                         /* preserve the rest of vars */
