@@ -80,7 +80,7 @@ static struct sql_connection *sql_conn[SQL_NSERVICE];
 static FILE  *sqlfd;
 static int line_no;
 static char *cur_line, *cur_ptr;
-static struct obstack parse_stack;
+static grad_strbuf_t parse_sb;
 static int stmt_type;
 
 static grad_keyword_t sql_keyword[] = {
@@ -153,7 +153,7 @@ get_conf_line(void)
         int cont;
 
         if (cur_line)
-                obstack_free(&parse_stack, cur_line);
+                grad_strbuf_free_string(parse_sb, cur_line);
         cont = 1;
         while (cont) {
                 ptr = fgets(buf, sizeof(buf), sqlfd);
@@ -178,13 +178,12 @@ get_conf_line(void)
                         continue;
                 total_length += eff_len;
                 /* add to the stack */
-                obstack_grow(&parse_stack, ptr, eff_len);
+                grad_strbuf_grow(parse_sb, ptr, eff_len);
         } 
 
         if (total_length == 0)
                 return NULL;
-        obstack_1grow(&parse_stack, 0);
-        cur_ptr = cur_line = obstack_finish(&parse_stack);
+        cur_ptr = cur_line = grad_strbuf_finish(parse_sb, 0);
         /* recognize keyword */
         while (*cur_ptr && !isspace(*cur_ptr))
                 cur_ptr++;
@@ -319,7 +318,7 @@ radiusd_sql_config(void)
         }
         line_no = 0;
         cur_line = NULL;
-        obstack_init(&parse_stack);
+        parse_sb = grad_strbuf_create();
         while (get_conf_line()) {
                 if (stmt_type == -1) {
                         grad_log(GRAD_LOG_ERR,
@@ -453,7 +452,7 @@ radiusd_sql_config(void)
                 
         }
 
-        obstack_free(&parse_stack, NULL);
+        grad_strbuf_free(parse_sb);
         fclose(sqlfd);
 
         sql_check_config(sqlfile, &new_cfg);
@@ -638,17 +637,17 @@ sql_cache_destroy(struct sql_connection *conn)
 static void
 sql_cache_insert(struct sql_connection *conn, SQL_RESULT *res)
 {
-	GRAD_DEBUG3(20, "cache: %d,(%d,%d)",
+	GRAD_DEBUG(20, "cache: %d,(%d,%d)",
 	            sql_cache_level(conn),conn->head,conn->tail);
 	if (sql_cache_level(conn) >= SQL_CACHE_SIZE-1) {
 		sql_result_destroy(conn->cache[conn->head]);
 		conn->head = (conn->head + 1) % SQL_CACHE_SIZE;
-	        GRAD_DEBUG2(20,"head: %d,%d", conn->head,conn->tail);
+	        GRAD_DEBUG(20,"head: %d,%d", conn->head,conn->tail);
 	}
-	GRAD_DEBUG1(20,"inserting at pos %d", conn->tail);
+	GRAD_DEBUG(20,"inserting at pos %d", conn->tail);
 	conn->cache[conn->tail] = res;
 	conn->tail = (conn->tail + 1) % SQL_CACHE_SIZE;
-	GRAD_DEBUG2(20,"tail: %d,%d", conn->head,conn->tail);
+	GRAD_DEBUG(20,"tail: %d,%d", conn->head,conn->tail);
 }
 
 static SQL_RESULT *
@@ -658,7 +657,7 @@ sql_cache_retrieve(struct sql_connection *conn, char *query)
 	SQL_RESULT *res;
 	size_t i;
 	
-	GRAD_DEBUG1(20,"query: %s",query);
+	GRAD_DEBUG(20,"query: %s",query);
 	res = grad_emalloc(sizeof(*res));
 	res->query = grad_estrdup(query);
 	res->nfields = res->ntuples = 0;
@@ -704,15 +703,15 @@ sql_cache_lookup(struct sql_connection *conn, char *query)
 {
 	size_t i;
 
-	GRAD_DEBUG1(20,"looking up %s", query);
+	GRAD_DEBUG(20,"looking up %s", query);
 	for (i = conn->head; i != conn->tail;
 	     i = (i + 1) % SQL_CACHE_SIZE) {
 		if (strcmp(conn->cache[i]->query, query) == 0) {
-			GRAD_DEBUG1(20,"found at %d", i);
+			GRAD_DEBUG(20,"found at %d", i);
 			return conn->cache[i];
 		}
 	}
-	GRAD_DEBUG(20,"NOT FOUND");
+	GRAD_DEBUG(20, "%s", "NOT FOUND");
 	return NULL;
 }
 
@@ -728,7 +727,7 @@ attach_sql_connection(int type)
         time(&now);
         conn = sql_conn[type];
         if (!conn) {
-                GRAD_DEBUG1(1, "allocating new %d sql connection", type);
+                GRAD_DEBUG(1, "allocating new %d sql connection", type);
 
                 conn = grad_emalloc(sizeof(struct sql_connection));
 		conn->cfg = &sql_cfg;
@@ -742,12 +741,12 @@ attach_sql_connection(int type)
         }
 
         if (!conn->connected || now - conn->last_used > sql_cfg.idle_timeout) {
-                GRAD_DEBUG1(1, "connection %d timed out: reconnect", type);
+                GRAD_DEBUG(1, "connection %d timed out: reconnect", type);
                 disp_sql_reconnect(sql_cfg.interface, type, conn);
         }
 	conn->destroy_on_close = !sql_cfg.keepopen;
         conn->last_used = now;
-        GRAD_DEBUG2(1, "attaching %p [%d]", conn, type);
+        GRAD_DEBUG(1, "attaching %p [%d]", conn, type);
         return conn;
 }
 
@@ -759,9 +758,9 @@ detach_sql_connection(int type)
         conn = sql_conn[type];
         if (!conn)
                 return;
-        GRAD_DEBUG2(1, "detaching %p [%d]", conn, type);
+        GRAD_DEBUG(1, "detaching %p [%d]", conn, type);
         if (conn->destroy_on_close) {
-                GRAD_DEBUG1(1, "destructing sql connection %p", conn);
+                GRAD_DEBUG(1, "destructing sql connection %p", conn);
 		sql_conn_destroy(&sql_conn[type]);
         }
 }
@@ -800,7 +799,6 @@ radiusd_sql_acct(radiusd_request_t *radreq)
         grad_avp_t *pair;
         char *query;
         struct sql_connection *conn;
-        struct obstack stack;
         char *query_name;
 	int log_facility = 0;
 	
@@ -817,71 +815,70 @@ radiusd_sql_acct(radiusd_request_t *radreq)
         status = pair->avp_lvalue;
 
         conn = attach_sql_connection(SQL_ACCT);
-        obstack_init(&stack);
 
         switch (status) {
         case DV_ACCT_STATUS_TYPE_START:
 		query_name = "acct_start_query";
                 if (!sql_cfg.query[acct_start_query])
                         break;
-                query = radius_xlate(&stack,
-                                     sql_cfg.query[acct_start_query],
+                query = radius_xlate(sql_cfg.query[acct_start_query],
                                      radreq->request, NULL);
                 rc = disp_sql_query(conn, query, NULL);
                 sqllog(rc, query);
 		log_facility = 0;
+		free(query);
                 break;
                 
         case DV_ACCT_STATUS_TYPE_STOP:
 		query_name = "acct_stop_query";
                 if (!sql_cfg.query[acct_stop_query])
                         break;
-                query = radius_xlate(&stack,
-                                     sql_cfg.query[acct_stop_query],
+                query = radius_xlate(sql_cfg.query[acct_stop_query],
                                      radreq->request, NULL);
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
                 if (rc == 0 && count != 1) 
 			log_facility = GRAD_LOG_WARN;
+		free(query);
                 break;
 
         case DV_ACCT_STATUS_TYPE_ACCOUNTING_ON:
 		query_name = "acct_nasup_query";
                 if (!sql_cfg.query[acct_nasup_query])
                         break;
-                query = radius_xlate(&stack,
-                                     sql_cfg.query[acct_nasup_query],
+                query = radius_xlate(sql_cfg.query[acct_nasup_query],
                                      radreq->request, NULL);
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
 		if (rc == 0)
 			log_facility = GRAD_LOG_INFO;
+		free(query);
                 break;
 
         case DV_ACCT_STATUS_TYPE_ACCOUNTING_OFF:
 		query_name = "acct_nasdown_query";
                 if (!sql_cfg.query[acct_nasdown_query])
                         break;
-                query = radius_xlate(&stack,
-                                     sql_cfg.query[acct_nasdown_query],
+                query = radius_xlate(sql_cfg.query[acct_nasdown_query],
                                      radreq->request, NULL);
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
 		if (rc == 0)
 			log_facility = GRAD_LOG_INFO;
+		free(query);
                 break;
 
         case DV_ACCT_STATUS_TYPE_ALIVE:
 		query_name = "acct_keepalive_query";
                 if (!sql_cfg.query[acct_keepalive_query])
                         break;
-                query = radius_xlate(&stack,
-                                     sql_cfg.query[acct_keepalive_query],
+                query = radius_xlate(sql_cfg.query[acct_keepalive_query],
                                      radreq->request, NULL);
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
                 if (rc == 0 && count != 1) 
 			log_facility = GRAD_LOG_WARN;
+		free(query);
                 break;
                 
         }
@@ -894,8 +891,6 @@ radiusd_sql_acct(radiusd_request_t *radreq)
 			     query_name,
 			     count);
 	}
-
-        obstack_free(&stack, NULL);
 }
 
 
@@ -905,7 +900,6 @@ radiusd_sql_pass(radiusd_request_t *req, char *authdata)
         char *mysql_passwd;
         struct sql_connection *conn;
         char *query;
-        struct obstack stack;
         
         if (sql_cfg.active[SQL_AUTH] == 0) {
                 grad_log(GRAD_LOG_ERR,
@@ -919,19 +913,16 @@ radiusd_sql_pass(radiusd_request_t *req, char *authdata)
 							 authdata));
         }
         
-        obstack_init(&stack);
-        query = radius_xlate(&stack, sql_cfg.query[auth_query],
+        query = radius_xlate(sql_cfg.query[auth_query],
 			     req->request, NULL);
         grad_avl_delete(&req->request->avlist, DA_AUTH_DATA);
         
         conn = attach_sql_connection(SQL_AUTH);
         mysql_passwd = disp_sql_getpwd(conn, query);
-	
+	free(query);
         if (mysql_passwd) 
                 chop(mysql_passwd);
         
-        obstack_free(&stack, NULL);
-        
         return mysql_passwd;
 }
 
@@ -941,7 +932,6 @@ radiusd_sql_checkgroup(radiusd_request_t *req, char *groupname)
         int   rc = -1;
         struct sql_connection *conn;
         char *query;
-        struct obstack stack;
 	SQL_RESULT *res;
 	size_t i;
 	
@@ -952,19 +942,16 @@ radiusd_sql_checkgroup(radiusd_request_t *req, char *groupname)
         if (!conn)
                 return -1;
 
-        obstack_init(&stack);
-	
-        query = radius_xlate(&stack, sql_cfg.query[group_query],
-			     req->request, NULL);
+        query = radius_xlate(sql_cfg.query[group_query], req->request, NULL);
 	res = sql_cache_lookup(conn, query);
 	if (!res) {
 		res = sql_cache_retrieve(conn, query);
 		if (!res) {
-			obstack_free(&stack, NULL);
+			free(query);
 			return -1;
 		}
 	}
-        obstack_free(&stack, NULL);
+        free(query);
 
 	if (res->ntuples == 0 || res->nfields == 0)
 		return rc;
@@ -1036,19 +1023,15 @@ radiusd_sql_reply_attr_query(radiusd_request_t *req, grad_avp_t **reply_pairs)
         struct sql_connection *conn;
         char *query;
         int rc;
-        struct obstack stack;
         
         if (sql_cfg.active[SQL_AUTH] == 0 || !sql_cfg.query[reply_attr_query])
                 return 0;
         
         conn = attach_sql_connection(SQL_AUTH);
-        obstack_init(&stack);
-
-        query = radius_xlate(&stack, sql_cfg.query[reply_attr_query],
+        query = radius_xlate(sql_cfg.query[reply_attr_query],
 			     req->request, NULL);
         rc = rad_sql_retrieve_pairs(conn, query, reply_pairs, 0);
-
-        obstack_free(&stack, NULL);
+	free(query);
         return rc == 0;
 }
 
@@ -1058,19 +1041,15 @@ radiusd_sql_check_attr_query(radiusd_request_t *req, grad_avp_t **return_pairs)
         struct sql_connection *conn;
         char *query;
         int rc;
-        struct obstack stack;
         
         if (sql_cfg.active[SQL_AUTH] == 0 || !sql_cfg.query[check_attr_query])
                 return 0;
         
         conn = attach_sql_connection(SQL_AUTH);
-        obstack_init(&stack);
-	
-        query = radius_xlate(&stack, sql_cfg.query[check_attr_query],
+        query = radius_xlate(sql_cfg.query[check_attr_query],
 			     req->request, NULL);
         rc = rad_sql_retrieve_pairs(conn, query, return_pairs, 1);
-        
-        obstack_free(&stack, NULL);
+        free(query);
         return rc == 0;
 }
 
@@ -1093,20 +1072,16 @@ radiusd_sql_auth_result_query(radiusd_request_t *req, int fail)
         struct sql_connection *conn;
         char *query;
         int rc;
-        struct obstack stack;
 	enum radius_sql_query q = fail ? auth_failure_query : auth_success_query;
 	
 	if (!sql_cfg.active[SQL_AUTH] || !sql_cfg.query[q])
 		return;
 
         conn = attach_sql_connection(SQL_AUTH);
-        obstack_init(&stack);
-	
-        query = radius_xlate(&stack, sql_cfg.query[q],
-			     req->request, NULL);
+        query = radius_xlate(sql_cfg.query[q], req->request, NULL);
 	rc = disp_sql_query(conn, query, NULL);
 	sqllog(rc, query);
-        obstack_free(&stack, NULL);
+	free(query);
 }
 
 
@@ -1155,15 +1130,11 @@ sql_mlc_collect(const char *query_template,
         struct sql_connection *conn;
         char *query;
         int rc;
-        struct obstack stack;
         
         conn = attach_sql_connection(SQL_ACCT);
-        obstack_init(&stack);
-	
-        query = radius_xlate(&stack, (char*) query_template,
-			     request->request, NULL);
+        query = radius_xlate(query_template, request->request, NULL);
         rc = rad_sql_retrieve_sessions(conn, query, sess_list);
-	obstack_free(&stack, NULL);
+	free(query);
         return rc == 0;
 }
 
@@ -1199,7 +1170,6 @@ rad_sql_mlc_close(struct radutmp *up)
 	int query_index = sql_cfg.query[mlc_stop_query] ?
 		                  mlc_stop_query : acct_stop_query;
 	char *query;
-	struct obstack stack;
 	grad_request_t *req;
 	int rc;
 	int count;
@@ -1208,7 +1178,6 @@ rad_sql_mlc_close(struct radutmp *up)
 	if (sql_cfg.active[SQL_ACCT] == 0 || !sql_cfg.query[query_index])
 		return;
 	conn = attach_sql_connection(SQL_ACCT);
-	obstack_init(&stack);
 	/* Create a temporary request */
 	req = grad_request_alloc();
 	grad_avl_add_pair(&req->avlist,
@@ -1222,10 +1191,11 @@ rad_sql_mlc_close(struct radutmp *up)
 	grad_avl_add_pair(&req->avlist,
 			  grad_avp_create_string(DA_ACCT_SESSION_ID,
 						 up->session_id));
-	query = radius_xlate(&stack, sql_cfg.query[query_index], req, NULL);
+	query = radius_xlate(sql_cfg.query[query_index], req, NULL);
 	grad_request_free(req);
 	rc = disp_sql_query(conn, query, &count);
 	sqllog(rc, query);
+	free(query);
 	if (rc == 0 && count != 1) {
 		grad_log(GRAD_LOG_WARN,
 			 ngettext("%s updated %d record",
@@ -1234,7 +1204,6 @@ rad_sql_mlc_close(struct radutmp *up)
 			 sql_query_name(query_index),
 			 count);
 	}
-	obstack_free(&stack, NULL);
 }
 
 
