@@ -33,10 +33,11 @@
 #include <assert.h>
 #include <signal.h>
 #include <netinet/in.h>
+#include <limits.h>
 
 #include <common.h>
 #include <radius/radutmp.h>
-#include <radius/radargp.h>
+#include <radcli.h>
 
 #define IP_ADDR_LEN 15
 
@@ -102,140 +103,256 @@ WTMP *login_list;
 /* List of NAS up/down transitions */
 WTMP *nas_updown_list;
 
-const char *argp_program_version = "radlast (" PACKAGE ") " VERSION;
-static char doc[] = N_("report last logins from Radius database.");
-
-static struct argp_option options[] = {
-        {NULL, 0, NULL, 0,
-         N_("radlast specific switches:"), 0},
-        {NULL, '0', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '1', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '2', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '3', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '4', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '5', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '6', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '7', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '8', NULL, OPTION_HIDDEN, NULL, 0},
-        {NULL, '9', NULL, OPTION_HIDDEN, NULL, 0},
-        {"count", 'c', N_("NUMBER"), 0,
-         N_("show at most NUMBER records"), 0},
-        {"file", 'f', N_("FILE"), 0,
-         N_("use FILE as radwtmp"), 0},
-        {"host", 'h', N_("IPADDR"), 0,
-         N_("show logins with IPADDR"), 0},
-        {"missed-stops", 'm', NULL, 0,
-         N_("mark records with missed stops with bump (!)"), 0},
-        {"nas", 'n', N_("NASNAME"), 0,
-         N_("show logins from given NAS"), 0},
-        {"long-format", 'l', NULL, 0,
-         N_("use long output format"), 0},
-        {"port", 'p', N_("NUMBER"), 0,
-         N_("show logins from given port"), 0},
-        {"show-seconds", 's', NULL, 0,
-         N_("show the login session duration in seconds"), 0},
-        {"wide", 'w', NULL, 0,
-         N_("widen the duration field to show seconds"), 0},
-        {NULL, 0, NULL, 0, NULL, 0}
-};
-
-static error_t
-parse_opt (int key, char *arg, struct argp_state *state)
+static int
+optset_digit(struct parseopt *po, struct optdef *opt, char *arg)
 {
-        switch (key) {
-        case '0': case '1': case '2': case '3': case '4':
-        case '5': case '6': case '7': case '8': case '9':
-                if (maxrec == -1) {
-                        char *p;
-			int i;
-			
-			if (state->argv[state->next-1][1] == key)
-				i = state->next-1;
-			else
-				i = state->next;
-                        maxrec = strtoul(state->argv[i]+1, &p, 0);
-                        if (!maxrec) {
-                                grad_log(GRAD_LOG_ERR,
-                                         "invalid number (near %s)",
-                                         p);
-                                exit(1);
-                        }
-                }
-                break;
-        case 'c':
-                maxrec = atol(arg);
-                if (!maxrec) {
-                        grad_log(GRAD_LOG_ERR, "invalid number of records");
-                        exit(1);
-                }
-                break;
-        case 'f':
-                file = arg;
-                break;
-        case 'h':
-                host_ip = htonl(grad_ip_gethostaddr(arg));
-                break;
-        case 'm':
-                mark_missing_stops++;
-                break;
-        case 'n':
-                nas_name = arg;
-                break;
-        case 'l':
-                long_fmt++;
-                break;
-        case 'p':
-                if (*arg == 's' || *arg == 'S')
-                        ++arg;
-                port = atoi(arg);
-                break;
-        case 's':
-                show_seconds++;        /* Show delta as seconds */
-                break;
-        case 't':
-                if (*arg == 's' || *arg == 'S')
-                        ++arg;
-                port = atoi(arg);
-                break;
-        case 'w':
-                width = 8;
-                break;
+	unsigned long i, k, n;
 
-        case ARGP_KEY_FINI:
-                if (show_seconds && width == 8) {
-                        grad_log(GRAD_LOG_ERR,
-                                 _("--width is incompatible with --show-seconds"));
-                        exit (1);
-                }
-                break;
-                
-        default:
-                return ARGP_ERR_UNKNOWN;
-        }
-        return 0;
+	if (arg) {
+		char *p;
+		errno = 0;
+		n = strtoul(arg, &p, 10);
+		if (errno || *p) {
+			po->po_error(po, PO_MSG_ERR,
+				     _("%s%s: invalid number"),
+				     opt->opt_name, arg);
+			exit(po->po_ex_usage);
+		}
+	} else
+		n = 0;
+
+	k = opt->opt_name[0] - '0';
+	for (i = n; i > 0; i /= 10)
+		k *= 10;
+	n += k;
+
+	if (n > INT_MAX) {
+		po->po_error(po, PO_MSG_ERR,
+			     _("%s%s: invalid number"),
+			     opt->opt_name, arg);
+		exit(po->po_ex_usage);
+	}
+
+	maxrec = n;
+
+	return 0;
 }
 
-static struct argp argp = {
-        options,
-        parse_opt,
-        NULL,
-        doc,
-        grad_common_argp_child,
-        NULL, NULL
+static int
+optset_hostip(struct parseopt *po, struct optdef *opt, char *arg)
+{
+	host_ip = htonl(grad_ip_gethostaddr(arg));
+	return 0;
+}
+
+static int
+optset_port(struct parseopt *po, struct optdef *opt, char *arg)
+{
+	unsigned long n;
+	char *p;
+	if (*arg == 's' || *arg == 'S')
+		++arg;
+	errno = 0;
+	n = strtoul(arg, &p, 10);
+	if (errno || *p || n > INT_MAX) {
+		po->po_error(po, PO_MSG_ERR, _("%s: invalid port"), arg);
+		exit(po->po_ex_usage);
+	}
+	*(int*)opt->opt_ptr = n;
+	return 0;
+}
+
+static int
+optset_wide(struct parseopt *po, struct optdef *opt, char *arg)
+{
+	width = 8;
+	return 0;
+}
+
+static struct optdef options[] = {
+        {
+		.opt_flags = OPTFLAG_DOC,
+		.opt_doc = N_("radlast specific switches:"),
+	},
+	{
+		.opt_name = "0",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "1",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "2",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "3",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "4",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "5",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "6",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "7",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "8",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+	{
+		.opt_name = "9",
+		.opt_argdoc = "",
+		.opt_flags = OPTFLAG_HIDDEN|OPTFLAG_ARG_OPTIONAL,
+		.opt_set = optset_digit
+	},
+
+	{
+		.opt_name = "count",
+		.opt_doc = N_("show at most NUMBER records"),
+		.opt_argdoc = N_("NUMBER"),
+		.opt_set = optset_int,
+		.opt_ptr = &maxrec
+	},
+	{
+		.opt_name = "c",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+
+	{
+		.opt_name = "file",
+		.opt_doc = N_("use FILE as radwtmp"),
+		.opt_argdoc = N_("FILE"),
+		.opt_set = optset_string_copy,
+		.opt_ptr = &file
+	},
+	{
+		.opt_name = "f",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+		
+        {
+		.opt_name = "host",
+		.opt_doc = N_("show logins with IPADDR"),
+		.opt_argdoc = N_("IPADDR"),
+		.opt_set = optset_hostip
+	},
+	{
+		.opt_name = "h",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+
+	{
+		.opt_name = "missed-stops",
+		.opt_doc = N_("mark records with missed stops with bump (!)"),
+		.opt_set = optset_true,
+		.opt_ptr = &mark_missing_stops
+	},
+	{
+		.opt_name = "m",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+
+        {
+		.opt_name = "nas",
+		.opt_doc = N_("show logins from given NAS"),
+		.opt_argdoc = N_("NASNAME"),
+		.opt_set = optset_string_copy,
+		.opt_ptr = &nas_name
+	},
+	{
+		.opt_name = "n",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+		
+        {
+		.opt_name = "long-format",
+		.opt_doc = N_("use long output format"),
+		.opt_set = optset_true,
+		.opt_ptr = &long_fmt
+	},
+	{
+		.opt_name = "l",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+
+        {
+		.opt_name = "port",
+		.opt_doc = N_("show logins from given port"),
+		.opt_argdoc = N_("NUMBER"),
+		.opt_set = optset_port,
+		.opt_ptr = &port
+	},
+	{
+		.opt_name = "p",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+		
+        {
+		.opt_name = "show-seconds",
+		.opt_doc = N_("show the login session duration in seconds"),
+		.opt_set = optset_true,
+		.opt_ptr = &show_seconds
+	},
+	{
+		.opt_name = "s",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+
+        {
+		.opt_name = "wide",
+		.opt_doc = N_("widen the duration field to show seconds"),
+		.opt_set = optset_wide,
+	},
+	{
+		.opt_name = "w",
+		.opt_flags = OPTFLAG_ALIAS
+	},
+
+        { NULL }
+}, *optdef[] = { options, NULL };
+
+static struct parseopt po = {
+	.po_descr = N_("report last logins from Radius database."),
+	.po_optdef = optdef,
+	.po_argdoc = N_("[OPTIONS] [USER...]")
 };
 
 int
 main(int argc, char **argv)
 {
-        int index;
-
+	set_progname(argv[0]);
         grad_app_setup();
-        if (grad_argp_parse(&argp, &argc, &argv, 0, &index, NULL))
-                return 1;
-
-        argv += index;
-        argc -= index;
-
+	grad_parseopt(&po, argc, argv, &argc, &argv);
+		
         if (argc) {
                 setlinebuf(stdout);
                 for (; *argv; ++argv) 
@@ -247,11 +364,11 @@ main(int argc, char **argv)
 
         if (nas_name) {
 		grad_nas_t *nas = grad_nas_lookup_name(nas_name);
-		if (!nas) {
-			if (grad_ip_getnetaddr(nas_name, &nas_ip)) {
-                                grad_log(GRAD_LOG_ERR, "unknown nas: %s", nas_name);
-                                return 1;
-                        }
+		if (nas) {
+			nas_ip = nas->netdef;
+		} else if (grad_ip_getnetaddr(nas_name, &nas_ip)) {
+			grad_log(GRAD_LOG_ERR, "unknown nas: %s", nas_name);
+			return 1;
                 }       
         }
         radwtmp();
