@@ -349,22 +349,23 @@ int radtest_eval(radtest_node_t *stmt, grad_list_t *list);
 
 /* Memory management */
 radtest_node_t *radtest_node_alloc(radtest_node_type);
-radtest_pair_t *radtest_pair_alloc();
+radtest_pair_t *radtest_pair_alloc(void);
 radtest_variable_t *radtest_var_alloc(radtest_data_type);
 radtest_variable_t *radtest_var_dup(radtest_variable_t *src);
 void radtest_var_copy (radtest_variable_t *dst, radtest_variable_t *src);
-radtest_pair_t *radtest_pair_alloc();
-radtest_case_branch_t *radtest_branch_alloc();
+radtest_pair_t *radtest_pair_alloc(void);
+radtest_case_branch_t *radtest_branch_alloc(void);
 void var_free(void *);
+void radtest_register_argv(char **argv);
 
-void radtest_free_mem();
-void radtest_fix_mem();
+void radtest_free_mem(void);
+void radtest_fix_mem(void);
 
 void radtest_start_string(char *str);
 void radtest_add_string(char *str);
-char *radtest_end_string();
-void radtest_free_strings();
-void radtest_fix_strings();
+char *radtest_end_string(void);
+void radtest_free_strings(void);
+void radtest_fix_strings(void);
 
 
 void radtest_env_add_string(grad_list_t *env, char *string);
