@@ -1,12 +1,12 @@
 /* 
    This file is part of GNU Radius SNMP Library.
-   Copyright (C) 2001,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 2.1 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this library.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -67,7 +65,7 @@ asn_decode_length(u_char *data, u_int *length)
    Return:Pointer to the byte immediately past the encoded length
    Error: NULL */
 u_char *
-asn_encode_length(u_char *data, int *datalength, u_int length)
+asn_encode_length(u_char *data, u_int *datalength, u_int length)
 {
         if (*datalength < 1) {
                 SNMP_SET_ERRNO(E_ASN_ENCODE);
@@ -118,7 +116,7 @@ asn_recode_length(u_char *data, u_int length)
           data).
    Error: NULL */
 u_char *
-asn_encode_header(u_char *data, int *datalength, u_char type, int length)
+asn_encode_header(u_char *data, u_int *datalength, u_char type, int length)
 {
         if (*datalength < 1) {
                 SNMP_SET_ERRNO(E_ASN_ENCODE);
@@ -130,7 +128,7 @@ asn_encode_header(u_char *data, int *datalength, u_char type, int length)
 }
 
 u_char *
-asn_decode_header(u_char *data, int *datalength, u_char *type)
+asn_decode_header(u_char *data, u_int *datalength, u_char *type)
 {
         if (*datalength < 1) {
                 SNMP_SET_ERRNO(E_ASN_DECODE);
@@ -142,7 +140,7 @@ asn_decode_header(u_char *data, int *datalength, u_char *type)
 }
 
 u_char *
-asn_encode_null(u_char *data, int *datalength, u_char type)
+asn_encode_null(u_char *data, u_int *datalength, u_char type)
 {
         return asn_encode_header(data, datalength, type, 0);
 }
@@ -162,7 +160,7 @@ asn_encode_null(u_char *data, int *datalength, u_char type)
    Return:Pointer to the byte immediately past the decoded object.
    Error: NULL */
 u_char *
-asn_decode_int(u_char *data, int *datalength, u_char *type,
+asn_decode_int(u_char *data, u_int *datalength, u_char *type,
 	       int *intp, int intsize)
 {
         u_int count;
@@ -209,7 +207,7 @@ asn_decode_int(u_char *data, int *datalength, u_char *type,
    Error: NULL */
    
 u_char *
-asn_encode_int(u_char *data, int *datalength, u_char type, int intval)
+asn_encode_int(u_char *data, u_int *datalength, u_char type, int intval)
 {
         u_int mask;
         u_int intsize = sizeof(int);
@@ -262,8 +260,8 @@ asn_encode_int(u_char *data, int *datalength, u_char type, int intval)
    Return:Pointer to the byte immediately past the decoded object.
    Error: NULL */
 u_char *
-asn_decode_string(u_char *data, int *datalength, u_char *type,
-		  u_char *string, int *strlength)
+asn_decode_string(u_char *data, u_int *datalength, u_char *type,
+		  u_char *string, u_int *strlength)
 {
         u_char *buf = data;
         u_int count;
@@ -293,8 +291,8 @@ asn_decode_string(u_char *data, int *datalength, u_char *type,
    Return:Pointer to the byte immediately past the encoded object.
    Error: NULL */
 u_char *
-asn_encode_string(u_char *data, int *datalength, u_char type,
-		  u_char *string, int strlength)
+asn_encode_string(u_char *data, u_int *datalength, u_char type,
+		  u_char *string, u_int strlength)
 {
         data = asn_encode_header(data, datalength, type, strlength);
         if (!data || *datalength < strlength) {
@@ -329,8 +327,8 @@ asn_encode_string(u_char *data, int *datalength, u_char type,
    Return:Pointer to the byte immediately past the decoded object.
    Error: NULL */
 u_char *
-asn_decode_oid(u_char *data, int *datalength, u_char *type,
-	       oid_t obid, int *obidlength)
+asn_decode_oid(u_char *data, u_int *datalength, u_char *type,
+	       oid_t obid, u_int *obidlength)
 {
         u_char *buf = data;
         u_int count;
@@ -385,10 +383,10 @@ asn_decode_oid(u_char *data, int *datalength, u_char *type,
    Return:Pointer to the byte immediately past the encoded object.
    Error: NULL */
 u_char *
-asn_encode_oid(u_char *data, int *datalength, u_char type,
-	       oid_t obid, int obidlength)
+asn_encode_oid(u_char *data, u_int *datalength, u_char type,
+	       oid_t obid, u_int obidlength)
 {
-        int length;
+        u_int length;
         u_char *buf, *bp;
         u_int subid;
         
