@@ -1,12 +1,12 @@
 /*
    This file is part of GNU Radius SNMP Library.
-   Copyright (C) 2001,2003 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 2.1 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
@@ -14,18 +14,16 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #include <stdlib.h>
-#include <asn1.h>
-#include <snmp.h>
+#include <snmp/asn1.h>
+#include <snmp/snmp.h>
 
 int
 snmp_send(struct snmp_session *sess, struct snmp_pdu *pdu)
@@ -68,7 +66,7 @@ int
 snmp_request_xmit(struct snmp_session *sess, struct snmp_request *req)
 {
         u_char packet_buf[SNMP_PACKET_LENGTH];
-        int length;
+        u_int length;
         struct timeval tv;
 
         length = sizeof(packet_buf);
@@ -101,7 +99,7 @@ snmp_request_xmit(struct snmp_session *sess, struct snmp_request *req)
 
 int
 snmp_encode_request(struct snmp_session *sess, struct snmp_pdu *pdu,
-		    u_char *packet_buf, int *length)
+		    u_char *packet_buf, u_int *length)
 {
         u_char *buf, *msg_start, *pdu_header_ptr, *pdu_data_start,
                *var_header_ptr, *var_data_start;
@@ -123,7 +121,7 @@ snmp_encode_request(struct snmp_session *sess, struct snmp_pdu *pdu,
         /* community */
         buf = asn_encode_string(buf, length,
                                (ASN_UNIVERSAL | ASN_PRIMITIVE | ASN_OCTET_STR),
-                                sess->community.str,
+                                (u_char*)sess->community.str,
                                 sess->community.len);
         BAIL_OUT;
 
@@ -158,7 +156,7 @@ snmp_encode_request(struct snmp_session *sess, struct snmp_pdu *pdu,
 
 int
 snmp_decode_request(struct snmp_session *sess, struct snmp_pdu *pdu,
-		    u_char *packet, int length, char *comm, int *comm_len)
+		    u_char *packet, u_int length, char *comm, u_int *comm_len)
 {
         int vers;
         u_char *buf;
@@ -176,7 +174,7 @@ snmp_decode_request(struct snmp_session *sess, struct snmp_pdu *pdu,
         if (!buf)
                 return -1;
 
-        buf = asn_decode_string(buf, &length, &type, comm, comm_len);
+        buf = asn_decode_string(buf, &length, &type, (u_char*) comm, comm_len);
         if (!buf)
                 return -1;
 
