@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000-2025 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
   
    You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   along with GNU Radius.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -23,6 +22,7 @@
 
 #include <common.h>
 #include <radsql.h>
+#include <radiusd.h>
 
 #include "modlist.h"
 
@@ -33,7 +33,7 @@ size_t sql_disptab_next;
 size_t sql_disptab_size;
 
 static void
-init_disptab()
+init_disptab(void)
 {
 	size_t size;
 	
@@ -51,7 +51,7 @@ add_disptab(SQL_DISPATCH_TAB *tab)
 {
 	if (sql_disptab_next == sql_disptab_size) {
 		sql_disptab_size += 4;
-		sql_disptab = grad_realloc(sql_disptab, sql_disptab_size);
+		sql_disptab = grad_erealloc(sql_disptab, sql_disptab_size);
 	}
 	sql_disptab[sql_disptab_next] = tab;
 	return sql_disptab_next++;
@@ -66,9 +66,9 @@ before_config_hook(void *a ARG_UNUSED, void *b ARG_UNUSED)
 }
 
 void
-disp_init()
+disp_init(void)
 {
-	radiusd_set_preconfig_hook(before_config_hook, NULL, NULL);
+	radiusd_set_preconfig_hook(before_config_hook, NULL, 0);
 }
 
 int
@@ -82,7 +82,7 @@ disp_sql_interface_index(char *name)
                 if (sql_disptab[i]
                     && (!name || strcmp(sql_disptab[i]->name, name) == 0))
                     return i;
-	if (name && radiusd_load_ext(name, "dispatch_tab", &tab))
+	if (name && radiusd_load_ext(name, "dispatch_tab", (void**) &tab))
 		return add_disptab(tab);
         return 0;
 }
@@ -127,7 +127,7 @@ disp_sql_disconnect(struct sql_connection *conn)
 }
 
 int
-disp_sql_query(struct sql_connection *conn, char *query, int *report_cnt)
+disp_sql_query(struct sql_connection *conn, const char *query, int *report_cnt)
 {
 	int rc;
 
@@ -135,12 +135,12 @@ disp_sql_query(struct sql_connection *conn, char *query, int *report_cnt)
 		return -1;
 	rc = disp_sql_entry(conn->interface)->query(conn, query, report_cnt);
 	if (rc) 
-		grad_log(L_ERR, "%s: %s", _("Failed query was"), query);
+		grad_log(GRAD_LOG_ERR, "%s: %s", _("Failed query was"), query);
 	return rc;
 }
 
 char *
-disp_sql_getpwd(struct sql_connection *conn, char *query)
+disp_sql_getpwd(struct sql_connection *conn, const char *query)
 {
 	if (!conn)
 		return NULL;
@@ -148,7 +148,7 @@ disp_sql_getpwd(struct sql_connection *conn, char *query)
 }
 
 void *
-disp_sql_exec(struct sql_connection *conn, char *query)
+disp_sql_exec(struct sql_connection *conn, const char *query)
 {
         return disp_sql_entry(conn->interface)->exec_query(conn, query);
 }
